# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name ShellCheck

%ifnarch armv7hl
%bcond_without tests
%endif

Name:           %{pkg_name}
Version:        0.3.8
Release:        1%{?dist}
Summary:        Shell script analysis tool

License:        GPLv3+
Url:            https://github.com/koalaman/shellcheck
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  chrpath
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-json-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-transformers-devel
# End cabal-rpm deps
BuildRequires:  pandoc

%description
The goals of ShellCheck are:

* To point out and clarify typical beginner's syntax issues,
  that causes a shell to give cryptic error messages.

* To point out and clarify typical intermediate level semantic problems,
  that causes a shell to behave strangely and counter-intuitively.

* To point out subtle caveats, corner cases and pitfalls, that may cause an
  advanced user's otherwise working script to fail under future circumstances.


%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.


%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Provides:       ghc-%{name}-static = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       ghc-%{name}%{?_isa} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.


%prep
%setup -q


%build
%ghc_lib_build

pandoc -s -t man shellcheck.1.md -o shellcheck.1


%install
%ghc_lib_install

install -Dpm 0644 shellcheck.1 %{buildroot}%{_mandir}/man1/shellcheck.1

%ghc_fix_dynamic_rpath shellcheck

rm %{buildroot}%{ghc_pkgdocdir}/LICENSE


%check
%if %{with tests}
%cabal test
%endif


%post -n ghc-%{name}-devel
%ghc_pkg_recache


%postun -n ghc-%{name}-devel
%ghc_pkg_recache


%files
%license LICENSE
%doc README.md
%{_bindir}/shellcheck
%{_mandir}/man1/shellcheck.1*


%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE


%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc README.md


%changelog
* Mon Mar  7 2016 Jens Petersen <petersen@redhat.com> - 0.3.8-1
- update to 0.3.8
- skip tests on armv7hl

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Apr 26 2015 Dridi <dridi.boukelmoune@gmail.com> - 0.3.7-1
- bumped to version 0.3.7
- updated summary with cabal's synopsis
- removed profiling symbols causing an FTBFS
- replaced regex-compat with regex-tdfa

* Wed Jan 28 2015 Jens Petersen <petersen@redhat.com> - 0.3.5-1
- update to 0.3.5

* Tue Nov  4 2014 Jens Petersen <petersen@redhat.com> - 0.3.4-2
- disable tests on all archs (#1158522)
  - QuickCheck should really only be used for buildtime tests

* Thu Sep 11 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.4-1
- bumped to version 0.3.4
- switched to hackage for the source tarball
- tests are now driven by cabal
- skip tests on ARM since TemplateHaskell fails

* Fri Sep  5 2014 Jens Petersen <petersen@redhat.com> - 0.3.3-2
- reenable pandoc on ARM

* Thu Sep 04 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.3-1
- rebuilt after a dependency upgrade

* Sat Aug 30 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.3-0
- bumped to version 0.3.3
- removed upstreamed patch

* Thu Aug 28 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.1-9
- rebuilt after a dependency upgrade

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Mar 17 2014 Jens Petersen <petersen@redhat.com> - 0.3.1-6
- fix shellcheck rpath instead of using ld.so.conf.d
- simplify doc files

* Sun Mar 16 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.1-5
- added missing ld config

* Sat Mar 01 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.1-4
- executable dynamically linked to the library (bug #1069048)

* Sun Feb 09 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.1-3
- removed Setup.hs, now available upstream
- stop building the man page on ARM, no pandoc (bug #992430)
- simpler workaroudn for bug #1052117

* Wed Feb 05 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.1-2
- build and install the man page

* Tue Feb 04 2014 Dridi <dridi.boukelmoune@gmail.com> - 0.3.1-1
- bumped to version 0.3.1
- added a workaround for the Fedora haskell toolchain (bug #1052117)

* Tue Dec 03 2013 Dridi <dridi.boukelmoune@gmail.com> - 0.2.0-3
- rebuilt

* Tue Dec 03 2013 Dridi Boukelmoune <dridi.boukelmoune@gmail.com> - 0.2.0-3
- s/shell/POSIX shell/ in summary
- LICENSE and README co-owned by sub-packages

* Sat Nov 30 2013 Dridi Boukelmoune <dridi.boukelmoune@gmail.com> - 0.2.0-2
- added a patch for "for arg do" loops (d4bc0f6)

* Sat Nov 23 2013 Dridi Boukelmoune <dridi.boukelmoune@gmail.com> - 0.2.0-1
- spec file generated by cabal-rpm-0.8.6
- added the description from the README
- fixed broken bits from the generated spec
